..
    This file is part of Invenio.
    Copyright (C) 2016-2021 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


Changes
=======

Version 2.8.8 (released 2022-07-12)
-----------------------------------
- bugfix: display community logo in the header

Version 2.8.7 (released 2022-07-08)
-----------------------------------

- add multiple destinations search bar
- search: redesign community search result item
- invitations: add helptext on member search
- settings: add file logo size limit
- add error handling for UUID

Version 2.8.6 (released 2022-07-01)
-----------------------------------
- requests search: add expanded fields, re-design list view
- community: update members table, add responsive width for grid columns
- members: reserve space for success/error icon, clean up table class
- global: fixes strings marked for translation
- community header: add community visibility to header
- dependencies: bump minor version of invenio-requests

Version 2.8.5 (released 2022-06-24)
-----------------------------------
- i18n: fix naming

Version 2.8.4 (released 2022-06-23)
-----------------------------------

- i18n: add german to list of languages
- homepage: align searchbar and button
- page subheader: add mobile class

Version 2.8.3 (released 2022-06-21)
-----------------------------------

- resources: add UI serializer
- i18n: clean up translation strings
- community logo: add fixed height for pictures
- settings ui: fix state behaviour
- members landing page: fix alignment

Version 2.8.2 (released 2022-06-08)
-----------------------------------

- search bar: fix search event propagation
- UI: remove redundant components
- members: style action dropdowns
- global: pin sphinx package
- global: add black formatter

Version 2.8.1 (released 2022-05-24)

- rename featured communities section

Version 2.8.0 (released 2022-05-23)


Version 2.3.1 (released 2021-06-10)
-----------------------------------

- Remove invenio dependencies to depend only on rdm-records.


Version 2.3.0 (released 2021-05-28)
-----------------------------------

- Improve visual feedback when changing permissions.
- Align facets with new records-resources faceting paradigm.


Version 2.2.5 (released 2021-04-29)
-----------------------------------

- Initial public release.
